@@ -87,3 +87,9 @@ class MapfwBenchmarker:
         self.attempt_id = r.json()["attempt"]
 
         self.status = {"state": "RUNNING", "data": {"problem_states": [0 for _ in self.problems]}}
+
+def get_all_benchmarks(without=None):
+    if not without:
+        without = []
+    r = requests.get("https://mapfw.nl/benchmarks/list.json")
+    return [problem for problem in r.json() if problem not in without]
\ No newline at end of file
